Command Line Interface
======================
autoreviewer automatically installs the command :code:`autoreviewer`. See
:code:`autoreviewer --help` for usage details.

.. click:: autoreviewer.cli:main
   :prog: autoreviewer
   :show-nested:
